diff --git a/jrx/src/popup.ts b/jrx/src/popup.ts
index c2ae7b9..05c8904 100644
--- a/jrx/src/popup.ts
+++ b/jrx/src/popup.ts
@@ -253,12 +253,12 @@ pi_repop
this_li.appendChild(rkp_ul);
- // if active, make background green
+ // if active, make background "active"
if (this_rkp.active)
- this_li.style.background = 'green';
- // otherwise make background red and add activate li
+ this_li.classList.add('account-active');
+ // otherwise make background "inactive" and add activate li
else {
- this_li.style.background = 'red';
+ this_li.classList.add('account-inactive');
let activate_li = document.createElement('li');
let activate_a = document.createElement('a');
activate_a.innerHTML = 'Switch to this key';